@@ -381,7 +381,7 @@ class Points(Layer):
         name=None,
         opacity=1.0,
         out_of_slice_display=False,
-        projection_mode='none',
+        projection_mode='all',
         properties=None,
         property_choices=None,
         rotate=None,
@@ -411,6 +411,7 @@ class Points(Layer):
         # Indices of selected points
         self._selected_data_stored = set()
         self._selected_data_history = set()
+        self._selected_data: Selection[int] = Selection()
         # Indices of selected points within the currently viewed slice
         self._selected_view = []
         # Index of hovered point
@@ -418,6 +419,8 @@ class Points(Layer):
         self._value_stored = None
         self._highlight_index = []
         self._highlight_box = None
+        self._mode = Mode.PAN_ZOOM
+        self._status = self.mode
 
         self._drag_start = None
         self._drag_normal = None
@@ -495,13 +498,6 @@ class Points(Layer):
         self._border_width_is_relative = False
         self._shown = np.empty(0).astype(bool)
 
-        # Indices of selected points
-        self._selected_data: Selection[int] = Selection()
-        self._selected_data_stored = set()
-        self._selected_data_history = set()
-        # Indices of selected points within the currently viewed slice
-        self._selected_view = []
-
         # The following point properties are for the new points that will
         # be added. For any given property, if a list is passed to the
         # constructor so each point gets its own value then the default
@@ -514,12 +510,6 @@ class Points(Layer):
             np.asarray(symbol) if np.isscalar(symbol) else 'o'
         )
 
-        # Index of hovered point
-        self._value = None
-        self._value_stored = None
-        self._mode = Mode.PAN_ZOOM
-        self._status = self.mode
-
         color_properties = (
             self._feature_table.properties()
             if self._data.size > 0
@@ -600,6 +590,7 @@ class Points(Layer):
         else:
             kwargs['action'] = ActionType.REMOVED
         self.events.data(**kwargs)
+        self.events.features()
 
     def _set_data(self, data: np.ndarray | None) -> None:
         """Set the .data array attribute, without emitting an event."""
@@ -637,16 +628,10 @@ class Points(Layer):
                 adding = len(data) - cur_npoints
                 size = np.repeat(self.current_size, adding, axis=0)
 
-                if len(self._border_width) > 0:
-                    new_border_width = copy(self._border_width[-1])
-                else:
-                    new_border_width = self.current_border_width
+                new_border_width = self.current_border_width
                 border_width = np.repeat([new_border_width], adding, axis=0)
 
-                if len(self._symbol) > 0:
-                    new_symbol = copy(self._symbol[-1])
-                else:
-                    new_symbol = self.current_symbol
+                new_symbol = self.current_symbol
                 symbol = np.repeat([new_symbol], adding, axis=0)
 
                 # Add new colors, updating the current property value before
@@ -2005,10 +1990,11 @@ class Points(Layer):
         self.events.data(
             value=self.data,
             action=ActionType.ADDED,
-            data_indices=tuple(np.arange(-len(coords), 0)),
+            data_indices=tuple(np.arange(-len(np.atleast_2d(coords)), 0)),
             vertex_indices=((),),
         )
         self.selected_data = set(np.arange(cur_points, len(self.data)))
+        self.events.features()
 
     def remove_selected(self) -> None:
         """Removes selected points if any."""
@@ -2054,6 +2040,7 @@ class Points(Layer):
                 vertex_indices=((),),
             )
             self.selected_data = set()
+            self.events.features()
 
     def _move(
         self,
@@ -2085,6 +2072,7 @@ class Points(Layer):
                 data_indices=tuple(selection_indices),
                 vertex_indices=((),),
             )
+            self.events.features()
 
     def _set_drag_start(
         self,
